@@ -2,6 +2,8 @@ import React, { useState, useCallback } from 'react';
 import PropTypes from 'prop-types';
 import classnames from 'classnames';
 import { CAPTURE_INFO_SHOW_KEY } from '../../../../../constants';
+import { gettext } from '../../../../../utils/constants';
+import OpElement from '../../../../op-element';
 
 import './index.css';
 
@@ -17,9 +19,13 @@ const Collapse = ({ className, title, children, isShow = true }) => {
     <div className={classnames('file-details-collapse', className)}>
       <div className="file-details-collapse-header">
         <div className="file-details-collapse-header-title">{title}</div>
-        <div className="file-details-collapse-header-operation" onClick={toggleShowChildren}>
-          <i aria-hidden="true" className={`sf3-font sf3-font-down ${showChildren ? '' : 'rotate-90'}`}></i>
-        </div>
+        <OpElement
+          className="file-details-collapse-header-operation"
+          op={toggleShowChildren}
+          title={showChildren ? gettext('Fold') : gettext('Unfold')}
+        >
+          <i className={`sf3-font sf3-font-down ${showChildren ? '' : 'rotate-90'}`}></i>
+        </OpElement>
       </div>
       {showChildren && (
         <div className="file-details-collapse-body">
