@@ -426,12 +426,14 @@ class Search extends Component {
 
     this.source = seafileAPI.getSource();
 
-    const query_type = 'library';
-    let results = [];
-    searchAPI.searchItems(query_str, query_type, this.source.token).then(res => {
-      results = [...results, ...this.formatResultItems(res.data.results)];
+    if (query_str.trim() === '') return;
+    this.setState({
+      isLoading: true,
+      resultItems: [],
+    });
+    searchAPI.searchRepos(query_str.trim()).then(res => {
       this.setState({
-        resultItems: results,
+        resultItems: this.formatResultItems(res.data.results),
         isLoading: false,
       });
     }).catch(error => {
@@ -519,7 +521,6 @@ class Search extends Component {
       items[i]['repo_id'] = data[i].repo_id;
       items[i]['repo_name'] = data[i].repo_name;
       items[i]['is_dir'] = data[i].is_dir;
-      items[i]['link_content'] = decodeURI(data[i].fullpath).substring(1);
       items[i]['content'] = data[i].content_highlight;
       items[i]['thumbnail_url'] = data[i].thumbnail_url;
       items[i]['mtime'] = data[i].mtime || '';
@@ -611,6 +612,7 @@ class Search extends Component {
               className={classnames('search-types-repos', { 'search-types-highlight': highlightIndex === 0 })}
               onClick={this.searchAllRepos}
               tabIndex={0}
+              onKeyDown={Utils.onKeyDown}
             >
               <i className="search-icon-left input-icon-addon sf3-font sf3-font-search"></i>
               {inputValue}
@@ -650,19 +652,40 @@ class Search extends Component {
       if (path && path !== '/' && !this.props.isViewFile && !isMetadataView && !isTagView) {
         return (
           <div className="search-types">
-            <div className={`search-types-repo ${highlightIndex === 0 ? 'search-types-highlight' : ''}`} onClick={this.searchRepo} tabIndex={0}>
+            <div
+              className={`search-types-repo ${highlightIndex === 0 ? 'search-types-highlight' : ''}`}
+              onClick={this.searchRepo}
+              tabIndex={0}
+              role="button"
+              aria-pressed={highlightIndex === 0}
+              onKeyDown={Utils.onKeyDown}
+            >
               <i className="search-icon-left input-icon-addon sf3-font sf3-font-search"></i>
               {inputValue}
               <span className="search-types-text">{gettext('in this library')}</span>
               {highlightIndex === 0 && <i className="sf3-font sf3-font-enter"></i>}
             </div>
-            <div className={`search-types-folder ${highlightIndex === 1 ? 'search-types-highlight' : ''}`} onClick={this.searchFolder} tabIndex={0}>
+            <div
+              className={`search-types-folder ${highlightIndex === 1 ? 'search-types-highlight' : ''}`}
+              onClick={this.searchFolder}
+              tabIndex={0}
+              role="button"
+              aria-pressed={highlightIndex === 1}
+              onKeyDown={Utils.onKeyDown}
+            >
               <i className="search-icon-left input-icon-addon sf3-font sf3-font-search"></i>
               {inputValue}
               <span className="search-types-text">{gettext('in this folder')}</span>
               {highlightIndex === 1 && <i className="sf3-font sf3-font-enter"></i>}
             </div>
-            <div className={`search-types-repos ${highlightIndex === 2 ? 'search-types-highlight' : ''}`} onClick={this.searchAllRepos} tabIndex={0}>
+            <div
+              className={`search-types-repos ${highlightIndex === 2 ? 'search-types-highlight' : ''}`}
+              onClick={this.searchAllRepos}
+              tabIndex={0}
+              role="button"
+              aria-pressed={highlightIndex === 2}
+              onKeyDown={Utils.onKeyDown}
+            >
               <i className="search-icon-left input-icon-addon sf3-font sf3-font-search"></i>
               {inputValue}
               <span className="search-types-text">{gettext('in all libraries')}</span>
@@ -673,13 +696,27 @@ class Search extends Component {
       } else {
         return (
           <div className="search-types">
-            <div className={`search-types-repo ${highlightIndex === 0 ? 'search-types-highlight' : ''}`} onClick={this.searchRepo} tabIndex={0}>
+            <div
+              className={`search-types-repo ${highlightIndex === 0 ? 'search-types-highlight' : ''}`}
+              onClick={this.searchRepo}
+              tabIndex={0}
+              role="button"
+              aria-pressed={highlightIndex === 0}
+              onKeyDown={Utils.onKeyDown}
+            >
               <i className="search-icon-left input-icon-addon sf3-font sf3-font-search"></i>
               {inputValue}
               <span className="search-types-text">{gettext('in this library')}</span>
               {highlightIndex === 0 && <i className="sf3-font sf3-font-enter"></i>}
             </div>
-            <div className={`search-types-repos ${highlightIndex === 1 ? 'search-types-highlight' : ''}`} onClick={this.searchAllRepos} tabIndex={0}>
+            <div
+              className={`search-types-repos ${highlightIndex === 1 ? 'search-types-highlight' : ''}`}
+              onClick={this.searchAllRepos}
+              tabIndex={0}
+              role="button"
+              aria-pressed={highlightIndex === 1}
+              onKeyDown={Utils.onKeyDown}
+            >
               <i className="search-icon-left input-icon-addon sf3-font sf3-font-search"></i>
               {inputValue}
               <span className="search-types-text">{gettext('in all libraries')}</span>
@@ -824,8 +861,8 @@ class Search extends Component {
 
     if (filters.date.value) {
       const isCustom = filters.date.value === SEARCH_FILTER_BY_DATE_OPTION_KEY.CUSTOM;
-      params.time_from = isCustom ? filters.date.start?.unix() : filters.date.from;
-      params.time_to = isCustom ? filters.date.end?.unix() : filters.date.to;
+      params.time_from = isCustom ? filters.date.from?.unix() : filters.date.from;
+      params.time_to = isCustom ? filters.date.to?.unix() : filters.date.to;
     }
 
     if (filters.suffixes) {
@@ -938,7 +975,8 @@ class Search extends Component {
                     title={isFiltersShow ? gettext('Hide advanced search') : gettext('Show advanced search')}
                     aria-label={isFiltersShow ? gettext('Hide advanced search') : gettext('Show advanced search')}
                     tabIndex={0}
-                    id="search-filter-controller"
+                    role="button"
+                    onKeyDown={Utils.onKeyDown}
                   />
                 )}
               </div>
