@@ -12,9 +12,13 @@ import { openInNewTab, openParentFolder } from '../../metadata/utils/file';
 import { checkIsDir } from '../../metadata/utils/row';
 import { getFileNameFromRecord } from '../../metadata/utils/cell';
 import { Utils } from '../../utils/utils';
+import OpIcon from '../../components/op-icon';
+import OpElement from '../../components/op-element';
 
-const FaceRecognitionFilesToolbar = (repoID) => {
+const FaceRecognitionFilesToolbar = ({ repoID }) => {
   const [selectedRecordIds, setSelectedRecordIds] = useState([]);
+  const [selectedRecords, setSelectedRecords] = useState([]);
+  const [isSomeone, setIsSomeone] = useState(false);
   const menuRef = useRef(null);
   const metadataRef = useRef([]);
 
@@ -31,12 +35,12 @@ const FaceRecognitionFilesToolbar = (repoID) => {
     };
   }, []);
 
-  const selectedRecords = useMemo(() => selectedRecordIds.map(id => RowUtils.getRecordById(id, metadataRef.current)).filter(Boolean) || [], [selectedRecordIds]);
-
   useEffect(() => {
-    const unsubscribeSelectedFileIds = eventBus && eventBus.subscribe(EVENT_BUS_TYPE.SELECT_RECORDS, (ids, metadata) => {
+    const unsubscribeSelectedFileIds = eventBus && eventBus.subscribe(EVENT_BUS_TYPE.SELECT_RECORDS, (ids, metadata, isSomeone) => {
       metadataRef.current = metadata;
       setSelectedRecordIds(ids);
+      setSelectedRecords(ids.map(id => RowUtils.getRecordById(id, metadataRef.current)).filter(Boolean) || []);
+      setIsSomeone(isSomeone);
     });
 
     return () => {
@@ -47,6 +51,7 @@ const FaceRecognitionFilesToolbar = (repoID) => {
 
   const unSelect = useCallback(() => {
     setSelectedRecordIds([]);
+    setSelectedRecords([]);
     eventBus && eventBus.dispatch(EVENT_BUS_TYPE.UPDATE_SELECTED_RECORD_IDS, []);
     eventBus.dispatch(EVENT_BUS_TYPE.SELECT_NONE);
   }, [eventBus]);
@@ -87,13 +92,13 @@ const FaceRecognitionFilesToolbar = (repoID) => {
       selectedRecords,
       readOnly,
       metadataStatus,
-      true,
+      isSomeone,
       faceRecognitionPermission
     );
-  }, [selectedRecords, enableTags, readOnly, faceRecognitionPermission]);
+  }, [selectedRecords, enableTags, readOnly, faceRecognitionPermission, isSomeone]);
 
   const onMenuItemClick = useCallback((option) => {
-    switch (option.key) {
+    switch (option) {
       case TextTranslation.OPEN_FILE_IN_NEW_TAB.key:
       case TextTranslation.OPEN_FOLDER_IN_NEW_TAB.key: {
         openInNewTab(repoID, selectedRecords[0]);
@@ -137,44 +142,58 @@ const FaceRecognitionFilesToolbar = (repoID) => {
         eventBus.dispatch(EVENT_BUS_TYPE.EXTRACT_TEXT, selectedRecords[0], menuRef.current.dropdownRef.current);
         break;
       }
-      case TextTranslation.REMOVE_FROM_GROUP:
-        eventBus && eventBus.dispatch(EVENT_BUS_TYPE.REMOVE_PHOTOS_FROM_CURRENT_SET, selectedRecords);
+      case TextTranslation.REMOVE_FROM_GROUP.key:
+        eventBus && eventBus.dispatch(EVENT_BUS_TYPE.REMOVE_PHOTOS_FROM_CURRENT_SET, selectedRecordIds);
         break;
-      case TextTranslation.ADD_TO_GROUPS:
+      case TextTranslation.ADD_TO_GROUPS.key:
         eventBus && eventBus.dispatch(EVENT_BUS_TYPE.ADD_PHOTO_TO_GROUPS);
         break;
-      case TextTranslation.SET_AS_COVER:
-        eventBus && eventBus.dispatch(EVENT_BUS_TYPE.SET_PHOTO_AS_COVER, selectedRecords[0]);
+      case TextTranslation.SET_AS_COVER.key:
+        eventBus && eventBus.dispatch(EVENT_BUS_TYPE.SET_PHOTO_AS_COVER, selectedRecordIds[0]);
         break;
       default:
         return;
     }
-  }, [repoID, eventBus, readOnly, selectedRecords]);
+  }, [repoID, eventBus, readOnly, selectedRecords, selectedRecordIds]);
 
   const length = selectedRecordIds.length;
   return (
     <div className="selected-dirents-toolbar">
-      <span className="cur-view-path-btn px-2" onClick={unSelect}>
-        <span className="sf3-font-x-01 sf3-font mr-2" aria-label={gettext('Unselect')} title={gettext('Unselect')}></span>
+      <OpElement
+        className="cur-view-path-btn px-2"
+        title={gettext('Unselect')}
+        op={unSelect}
+      >
+        <span className="sf3-font-x-01 sf3-font mr-2"></span>
         <span>{length}{' '}{gettext('selected')}</span>
-      </span>
+      </OpElement>
       {!readOnly && length === 1 && (
         <>
-          <span className="cur-view-path-btn" onClick={onMoveClick} title={gettext('Move')}>
-            <span className="sf3-font-move sf3-font" aria-label={gettext('Move')}></span>
-          </span>
-          <span className="cur-view-path-btn" onClick={onCopyClick} title={gettext('Copy')}>
-            <span className="sf3-font-copy1 sf3-font" aria-label={gettext('Copy')}></span>
-          </span>
+          <OpIcon
+            className="cur-view-path-btn sf3-font-move1 sf3-font"
+            title={gettext('Move')}
+            op={onMoveClick}
+          />
+          <OpIcon
+            className="cur-view-path-btn sf3-font-copy1 sf3-font"
+            title={gettext('Copy')}
+            op={onCopyClick}
+          />
         </>
       )}
-      <span className="cur-view-path-btn" onClick={handleDownload}>
-        <span className="sf3-font-download1 sf3-font" aria-label={gettext('Download')} title={gettext('Download')}></span>
-      </span>
+
+      <OpIcon
+        className="cur-view-path-btn sf3-font-download1 sf3-font"
+        title={gettext('Download')}
+        op={handleDownload}
+      />
+
       {!readOnly &&
-        <span className="cur-view-path-btn" onClick={deleteRecords}>
-          <span className="sf3-font-delete1 sf3-font" aria-label={gettext('Delete')} title={gettext('Delete')}></span>
-        </span>
+      <OpIcon
+        className="cur-view-path-btn sf3-font-delete1 sf3-font"
+        title={gettext('Delete')}
+        op={deleteRecords}
+      />
       }
       <ItemDropdownMenu
         ref={menuRef}
