@@ -3,7 +3,7 @@ import { getRowById, getRowsByIds } from '../../components/sf-table/utils/table'
 import { getColumnByKey, normalizeColumns } from '../utils/column';
 import {
   Operation, LOCAL_APPLY_OPERATION_TYPE, NEED_APPLY_AFTER_SERVER_OPERATION, OPERATION_TYPE, UNDO_OPERATION_TYPE,
-  VIEW_OPERATION, COLUMN_OPERATION
+  VIEW_OPERATION, COLUMN_OPERATION, NEED_LOADING_OPERATION
 } from './operations';
 import { EVENT_BUS_TYPE, PER_LOAD_NUMBER, PRIVATE_COLUMN_KEY, DEFAULT_RETRY_TIMES, DEFAULT_RETRY_INTERVAL } from '../constants';
 import DataProcessor from './data-processor';
@@ -116,6 +116,10 @@ class Store {
   applyOperation(operation, undoRedoHandler = { handleUndo: true }) {
     const { op_type } = operation;
 
+    if (NEED_LOADING_OPERATION.includes(op_type)) {
+      this.context.eventBus.dispatch(EVENT_BUS_TYPE.LOADING, true);
+    }
+
     if (!NEED_APPLY_AFTER_SERVER_OPERATION.includes(op_type)) {
       this.handleUndoRedos(undoRedoHandler, operation);
       this.data = deepCopy(operation.apply(this.data));
