@@ -218,6 +218,18 @@ class LibContentView extends React.Component {
           isSessionExpired: false,
           currentDirent: null,
         });
+
+        // Synchronize tree panel with updated directory list
+        if (this.state.isTreePanelShown && this.isTreeReady(this.state.path)) {
+          const currentPath = this.state.path;
+          const tree = this.state.treeData.clone();
+          const currentNode = tree.getNodeByPath(currentPath);
+
+          if (currentNode && currentNode.isLoaded) {
+            this.addResponseListToNode(dirent_list, currentNode);
+            this.setState({ treeData: tree });
+          }
+        }
       });
     }
   };
@@ -1565,11 +1577,8 @@ class LibContentView extends React.Component {
 
       this.setState(prevState => {
         const newDirentList = prevState.direntList.map(dirent => {
-          const isSelected = newSelectedDirentList.some(selected => selected.name === dirent.name);
-          return new Dirent({
-            ...dirent,
-            isSelected: isSelected,
-          });
+          dirent.isSelected = newSelectedDirentList.some(selected => selected.name === dirent.name);
+          return dirent;
         });
 
         const updatedSelectedDirents = newSelectedDirentList.map(selected =>
@@ -1585,25 +1594,24 @@ class LibContentView extends React.Component {
         };
       });
     } else {
-      this.setState(prevState => ({
-        direntList: prevState.direntList.map(dirent => new Dirent({ ...dirent, isSelected: false })),
+      this.setState({
+        direntList: direntList.map(dirent => {
+          dirent.isSelected = false;
+          return dirent;
+        }),
         isDirentSelected: false,
         isAllDirentSelected: false,
         selectedDirentList: [],
         lastSelectedIndex: null,
-      }));
+      });
     }
   };
 
   onSelectedDirentListUpdate = (newSelectedDirentList, lastSelectedIndex = null) => {
     this.setState({
       direntList: this.state.direntList.map(dirent => {
-        return new Dirent({
-          ...dirent,
-          isSelected: newSelectedDirentList.some(
-            selected => selected.name === dirent.name
-          )
-        });
+        dirent.isSelected = newSelectedDirentList.some(selectedDirent => selectedDirent.name === dirent.name);
+        return dirent;
       }),
       isDirentSelected: newSelectedDirentList.length > 0,
       selectedDirentList: newSelectedDirentList,
@@ -1759,9 +1767,17 @@ class LibContentView extends React.Component {
         direntList: direntObject.type === 'dir' ? [dirent, ...prevState.direntList] : [...prevState.direntList, dirent]
       }));
     }
-
-    if (this.state.isTreePanelShown && !isExist) {
-      this.addNodeToTree(dirent.name, this.state.path, dirent.type);
+    // Ensure tree reflects new dirents even if repo-update refreshed list earlier.
+    if (this.state.isTreePanelShown) {
+      const parentPath = this.state.path;
+      const nodePath = Utils.joinPath(parentPath, direntObject.name);
+      if (direntObject.type === 'dir') {
+        const tree = this.state.treeData.clone();
+        const nodeExists = !!tree.getNodeByPath(nodePath);
+        if (!nodeExists) {
+          this.addNodeToTree(direntObject.name, parentPath, 'dir');
+        }
+      }
     }
   };
 
