@@ -89,7 +89,7 @@ class Content extends Component {
                 <input
                   type="checkbox"
                   checked={isAllLinksSelected}
-                  className="vam"
+                  className="form-check-input"
                   onChange={this.toggleSelectAllLinks}
                   onKeyDown={Utils.onKeyDown}
                   aria-label={isAllLinksSelected ? gettext('Unselect items') : gettext('Select items')}
@@ -288,7 +288,7 @@ class Item extends Component {
               <input
                 type="checkbox"
                 checked={isSelected}
-                className="vam"
+                className="form-check-input"
                 onClick={this.onCheckboxClicked}
                 onChange={this.toggleSelectLink}
                 onKeyDown={Utils.onKeyDown}
