@@ -142,7 +142,7 @@ export const Utils = {
       return false;
     }
     const file_ext = filename.substr(filename.lastIndexOf('.') + 1).toLowerCase();
-    const image_exts = ['gif', 'jpeg', 'jpg', 'png', 'ico', 'bmp', 'tif', 'tiff', 'jfif', 'heic', 'webp'];
+    const image_exts = ['gif', 'jpeg', 'jpg', 'png', 'ico', 'bmp', 'tif', 'tiff', 'jfif', 'heic', 'webp', 'svg'];
     return image_exts.includes(file_ext);
   },
 
@@ -1894,7 +1894,7 @@ export const Utils = {
     let allSearchesArr = allSearches.split('&');
     allSearchesArr.forEach(item => {
       let itemArr = item.split('=');
-      searchParams[itemArr[0]] = decodeURI(itemArr[1]);
+      searchParams[itemArr[0]] = itemArr[1];
     });
     return searchParams;
   },
