@@ -39,7 +39,11 @@
     "30 Days": "30 dagen",
     "7 Days": "7 dagen",
     "A file is being uploaded. Are you sure you want to leave this page?": "A file is being uploaded. Are you sure you want to leave this page?",
+    "A file named {upload_file_link} is uploaded to {uploaded_link}.": "A file named {upload_file_link} is uploaded to {uploaded_link}.",
+    "A file named {upload_file_link} is uploaded.": "A file named {upload_file_link} is uploaded.",
     "A file with the same name already exists in this folder.": "Een bestand met deze naam bestaat reeds in deze map.",
+    "A folder named {upload_folder_link} is uploaded to {uploaded_link}.": "A folder named {upload_folder_link} is uploaded to {uploaded_link}.",
+    "A folder named {upload_folder_link} is uploaded.": "A folder named {upload_folder_link} is uploaded.",
     "API Token": "API Token",
     "API token is copied to the clipboard.": "API token is copied to the clipboard.",
     "About": "Over",
@@ -564,7 +568,6 @@
     "Library": "Bibliotheek",
     "Library Type": "Soort bibliotheek",
     "Library does not exist": "Bibliotheek bestaat niet",
-    "Library share permission not found.": "Library share permission not found.",
     "Limits": "Limieten",
     "Link": "Link",
     "Link has been copied to clipboard": "Link has been copied to clipboard",
@@ -649,7 +652,6 @@
     "New PowerPoint File": "Nieuw PowerPoint-bestand",
     "New SeaDoc File": "New SeaDoc File",
     "New Sub-department": "Nieuwe subafdeling",
-    "New Wiki name": "New Wiki name",
     "New Word File": "Nieuw Word-bestand",
     "New directories": "Nieuwe mappen",
     "New file name": "Nieuwe bestandsnaam",
@@ -1311,6 +1313,7 @@
     "xxx records": "xxx records",
     "xxx records selected": "xxx records selected",
     "xxx rows are copied.": "xxx rows are copied.",
+    "you can also press \u2192": "you can also press \u2192",
     "{failed_files_num} file(s) failed to upload": "{failed_files_num} file(s) failed to upload",
     "{file} and {n} other files": "{file} and {n} other files",
     "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} days",
