@@ -39,7 +39,11 @@
     "30 Days": "30 P\u00e4iv\u00e4\u00e4",
     "7 Days": "7 P\u00e4iv\u00e4\u00e4",
     "A file is being uploaded. Are you sure you want to leave this page?": "A file is being uploaded. Are you sure you want to leave this page?",
+    "A file named {upload_file_link} is uploaded to {uploaded_link}.": "A file named {upload_file_link} is uploaded to {uploaded_link}.",
+    "A file named {upload_file_link} is uploaded.": "A file named {upload_file_link} is uploaded.",
     "A file with the same name already exists in this folder.": "Hakemistossa on jo saman niminen tiedosto.",
+    "A folder named {upload_folder_link} is uploaded to {uploaded_link}.": "A folder named {upload_folder_link} is uploaded to {uploaded_link}.",
+    "A folder named {upload_folder_link} is uploaded.": "A folder named {upload_folder_link} is uploaded.",
     "API Token": "API Token",
     "API token is copied to the clipboard.": "API token is copied to the clipboard.",
     "About": "Tietoa",
@@ -564,7 +568,6 @@
     "Library": "Kirjasto",
     "Library Type": "Kirjaston tyyppi",
     "Library does not exist": "Kirjastoa ei ole",
-    "Library share permission not found.": "Library share permission not found.",
     "Limits": "Rajat",
     "Link": "Linkki",
     "Link has been copied to clipboard": "Link has been copied to clipboard",
@@ -648,7 +651,6 @@
     "New PowerPoint File": "Uusi PowerPoint tiedosto",
     "New SeaDoc File": "New SeaDoc File",
     "New Sub-department": "Uusi Aliosasto",
-    "New Wiki name": "New Wiki name",
     "New Word File": "Uusi Word tiedosto",
     "New directories": "Uudet hakemistot",
     "New file name": "New file name",
@@ -1307,6 +1309,7 @@
     "xxx records": "xxx records",
     "xxx records selected": "xxx records selected",
     "xxx rows are copied.": "xxx rows are copied.",
+    "you can also press \u2192": "you can also press \u2192",
     "{failed_files_num} file(s) failed to upload": "{failed_files_num} file(s) failed to upload",
     "{file} and {n} other files": "{file} and {n} other files",
     "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} days",
