@@ -39,7 +39,11 @@
     "30 Days": "30 nap",
     "7 Days": "7 nap",
     "A file is being uploaded. Are you sure you want to leave this page?": "A file is being uploaded. Are you sure you want to leave this page?",
+    "A file named {upload_file_link} is uploaded to {uploaded_link}.": "A file named {upload_file_link} is uploaded to {uploaded_link}.",
+    "A file named {upload_file_link} is uploaded.": "A file named {upload_file_link} is uploaded.",
     "A file with the same name already exists in this folder.": "A f\u00e1jl ezzel a n\u00e9vvel m\u00e1r l\u00e9tezik a k\u00f6nyvt\u00e1rban.",
+    "A folder named {upload_folder_link} is uploaded to {uploaded_link}.": "A folder named {upload_folder_link} is uploaded to {uploaded_link}.",
+    "A folder named {upload_folder_link} is uploaded.": "A folder named {upload_folder_link} is uploaded.",
     "API Token": "API Token",
     "API token is copied to the clipboard.": "API token is copied to the clipboard.",
     "About": "N\u00e9vjegy",
@@ -114,7 +118,6 @@
     "Are you sure to revoke access of user {placeholder} ?": "Are you sure to revoke access of user {placeholder} ?",
     "Are you sure you want to clear trash?": "Biztos, hogy \u00fcr\u00edti a kuk\u00e1t?",
     "Are you sure you want to delete": "Are you sure you want to delete",
-    "Are you sure you want to delete %s ?": "Biztosan t\u00f6rli: %s?",
     "Are you sure you want to delete WebDAV password?": "Are you sure you want to delete WebDAV password?",
     "Are you sure you want to delete the notification ?": "Are you sure you want to delete the notification ?",
     "Are you sure you want to delete the selected share link(s) ?": "Are you sure you want to delete the selected share link(s) ?",
@@ -316,7 +319,6 @@
     "Dimensions": "Dimensions",
     "Direct download link": "Direct download link",
     "Direct download link is copied to the clipboard.": "K\u00f6zvetlen let\u00f6lt\u00e9si link v\u00e1g\u00f3lapra m\u00e1solva",
-    "Disable SAML user email / password login": "Disable SAML user email / password login",
     "Disable Two-Factor Authentication": "K\u00e9tl\u00e9pcs\u0151s azonos\u00edt\u00e1s kikapcsol\u00e1sa",
     "Disconnect": "Disconnect",
     "Discussion": "Megbesz\u00e9l\u00e9s",
@@ -473,12 +475,12 @@
     "Folders": "K\u00f6nyvt\u00e1rak",
     "Force Two-Factor Authentication": "K\u00f6telez\u0151 k\u00e9tl\u00e9pcs\u0151s azonos\u00edt\u00e1s",
     "Force user to change password when account is newly added or reset by admin": "K\u00e9nyszer\u00edti a felhaszn\u00e1l\u00f3t jelszav\u00e1nak megv\u00e1ltoztat\u00e1s\u00e1ra, \u00faj felhaszn\u00e1l\u00f3i fi\u00f3k l\u00e9trehoz\u00e1sakor, vagy ha egy Adminisztr\u00e1tor alaphelyzetbe \u00e1ll\u00edtja azt.",
-    "Force user to use SSO login if SAML account is bound": "Force user to use SSO login if SAML account is bound",
     "Force user to use a strong password when sign up or change password.": "Megk\u00f6veteli a felhaszn\u00e1l\u00f3t\u00f3l er\u0151s jelsz\u00f3 haszn\u00e1lat\u00e1t regisztr\u00e1ci\u00f3 vagy jelsz\u00f3v\u00e1lt\u00e1s alkalm\u00e1val.",
     "Format": "Format",
     "Freeze Document": "Freeze Document",
     "Freeze user account when failed login attempts exceed limit.": "Felhaszn\u00e1l\u00f3i fi\u00f3k felf\u00fcggeszt\u00e9se, ha a sikertelen bejelentkez\u00e9si k\u00eds\u00e9rletek sz\u00e1ma el\u00e9rte a limitet.",
     "Frozen by {name}": "Frozen by {name}",
+    "Full screen": "Teljes k\u00e9perny\u0151",
     "Gallery": "Gallery",
     "General information": "General information",
     "Generate": "Gener\u00e1l",
@@ -570,7 +572,6 @@
     "Library": "K\u00f6tet",
     "Library Type": "K\u00f6tet t\u00edpusa",
     "Library does not exist": "A k\u00f6tet nem l\u00e9tezik",
-    "Library share permission not found.": "Library share permission not found.",
     "Limits": "Hat\u00e1rok",
     "Link": "Link",
     "Link has been copied to clipboard": "Link has been copied to clipboard",
@@ -655,7 +656,6 @@
     "New PowerPoint File": "\u00daj PowerPoint f\u00e1jl",
     "New SeaDoc File": "New SeaDoc File",
     "New Sub-department": "\u00daj aloszt\u00e1ly",
-    "New Wiki name": "New Wiki name",
     "New Word File": "\u00daj Word f\u00e1jl",
     "New directories": "\u00daj k\u00f6nyvt\u00e1rak",
     "New file name": "\u00daj f\u00e1jl neve",
@@ -809,7 +809,6 @@
     "Pictures and videos": "Pictures and videos",
     "Platform": "Platform",
     "Please check the network.": "Ellen\u0151rizze a h\u00e1l\u00f3zatot.",
-    "Please choose a .sdoczip file.": "Please choose a .sdoczip file.",
     "Please choose a .xlsx file.": "V\u00e1lasszon egy .xlsx f\u00e1jlt",
     "Please choose an image file.": "Please choose an image file.",
     "Please enter 1 or more character": "K\u00e9rem adjon meg m\u00e9g 1 vagy t\u00f6bb karaktert",
@@ -926,6 +925,7 @@
     "Search property": "Search property",
     "Search users": "Search users",
     "Search users...": "Felhaszn\u00e1l\u00f3k keres\u00e9se...",
+    "Searching...": "Keres\u00e9s...",
     "Select": "Kiv\u00e1laszt",
     "Select File": "F\u00e1jl kiv\u00e1laszt\u00e1sa",
     "Select a department": "Select a department",
@@ -1326,6 +1326,7 @@
     "xxx records": "xxx records",
     "xxx records selected": "xxx records selected",
     "xxx rows are copied.": "xxx rows are copied.",
+    "you can also press \u2192": "a \u2192 gombot is haszn\u00e1lhatja ",
     "{failed_files_num} file(s) failed to upload": "{failed_files_num} file(s) failed to upload",
     "{file} and {n} other files": "{file} \u00e9s {n} egy\u00e9b f\u00e1jl",
     "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} days",
