@@ -4,22 +4,24 @@ SCRIPT=$(readlink -f "$0") # haiwen/seafile-server-1.3.0/upgrade/upgrade_xx_xx.s
 UPGRADE_DIR=$(dirname "$SCRIPT") # haiwen/seafile-server-1.3.0/upgrade/
 INSTALLPATH=$(dirname "$UPGRADE_DIR") # haiwen/seafile-server-1.3.0/
 TOPDIR=$(dirname "${INSTALLPATH}") # haiwen/
+default_ccnet_conf_dir=${TOPDIR}/ccnet
 default_conf_dir=${TOPDIR}/conf
 default_pids_dir=${TOPDIR}/pids
 default_logs_dir=${TOPDIR}/logs
-default_seafile_data_dir=${TOPDIR}/seafile-data
 seafile_server_symlink=${TOPDIR}/seafile-server-latest
 seahub_data_dir=${TOPDIR}/seahub-data
+seahub_settings_py=${TOPDIR}/seahub_settings.py
 
 manage_py=${INSTALLPATH}/seahub/manage.py
 
-export SEAFILE_CONF_DIR=${default_seafile_data_dir}
+export CCNET_CONF_DIR=${default_ccnet_conf_dir}
 export SEAFILE_CENTRAL_CONF_DIR=${default_conf_dir}
-export PYTHONPATH=${INSTALLPATH}/seafile/lib/python3/site-packages:${INSTALLPATH}/seafile/lib64/python3/site-packages:${INSTALLPATH}/seahub:${INSTALLPATH}/seahub/thirdpart:$PYTHONPATH
+export PYTHONPATH=${INSTALLPATH}/seafile/lib/python2.6/site-packages:${INSTALLPATH}/seafile/lib64/python2.6/site-packages:${INSTALLPATH}/seafile/lib/python2.7/site-packages:${INSTALLPATH}/seahub/thirdpart:$PYTHONPATH
+export PYTHONPATH=${INSTALLPATH}/seafile/lib/python2.7/site-packages:${INSTALLPATH}/seafile/lib64/python2.7/site-packages:$PYTHONPATH
 export SEAFILE_LD_LIBRARY_PATH=${INSTALLPATH}/seafile/lib/:${INSTALLPATH}/seafile/lib64:${LD_LIBRARY_PATH}
 
-prev_version=12.0
-current_version=13.0
+prev_version=6.2
+current_version=6.3
 
 echo
 echo "-------------------------------------------------------------"
@@ -34,33 +36,35 @@ function check_python_executable() {
         return 0
     fi
 
-    if which python3 2>/dev/null 1>&2; then
-        PYTHON=python3
-    elif !(python --version 2>&1 | grep "3\.[0-9]\.[0-9]") 2>/dev/null 1>&2; then
+    if which python2.7 2>/dev/null 1>&2; then
+        PYTHON=python2.7
+    elif which python27 2>/dev/null 1>&2; then
+        PYTHON=python27
+    else
         echo
-        echo "The current version of python is not 3.x.x, please use Python 3.x.x ."
+        echo "Can't find a python executable of version 2.7 or above in PATH"
+        echo "Install python 2.7+ before continue."
+        echo "Or if you installed it in a non-standard PATH, set the PYTHON enviroment variable to it"
         echo
         exit 1
-    else
-        PYTHON="python"$(python --version | cut -b 8-20)
-        if !which $PYTHON 2>/dev/null 1>&2; then
-            echo
-            echo "Can't find a python executable of $PYTHON in PATH"
-            echo "Install $PYTHON before continue."
-            echo "Or if you installed it in a non-standard PATH, set the PYTHON enviroment variable to it"
-            echo
-            exit 1
-        fi
     fi
 }
 
-function check_seafile_data_dir () {
-    if [[ ! -d ${default_seafile_data_dir} ]]; then
-        echo "Your seafile server data directory \"${default_seafile_data_dir}\" is invalid or doesn't exits."
+function read_seafile_data_dir () {
+    seafile_ini=${default_ccnet_conf_dir}/seafile.ini
+    if [[ ! -f ${seafile_ini} ]]; then
+        echo "${seafile_ini} not found. Now quit"
+        exit 1
+    fi
+    seafile_data_dir=$(cat "${seafile_ini}")
+    if [[ ! -d ${seafile_data_dir} ]]; then
+        echo "Your seafile server data directory \"${seafile_data_dir}\" is invalid or doesn't exits."
         echo "Please check it first, or create this directory yourself."
         echo ""
         exit 1;
     fi
+
+    export SEAFILE_CONF_DIR=$seafile_data_dir
 }
 
 function ensure_server_not_running() {
@@ -115,7 +119,7 @@ function update_database() {
     echo
 
     db_update_helper=${UPGRADE_DIR}/db_update_helper.py
-    if ! $PYTHON "${db_update_helper}" 13.0.0; then
+    if ! $PYTHON "${db_update_helper}" 6.3.0; then
         echo
         echo "Failed to upgrade your database"
         echo
@@ -186,13 +190,37 @@ function move_old_customdir_outside() {
     cp -rf "${old_customdir}" "${seahub_data_dir}/"
 }
 
+function add_gunicorn_conf() {
+    gunicorn_conf=${default_conf_dir}/gunicorn.conf
+    if ! $(cat > ${gunicorn_conf} <<EOF
+import os
+
+daemon = True
+workers = 5
+
+# default localhost:8000
+bind = "127.0.0.1:8000"
+
+# Pid
+pids_dir = '$default_pids_dir'
+pidfile = os.path.join(pids_dir, 'seahub.pid')
+
+# for file upload, we need a longer timeout value (default is only 30s, too short)
+timeout = 1200
+
+limit_request_line = 8190
+EOF
+); then
+    echo "failed to generate gunicorn.conf";
+fi
+}
 
 #################
 # The main execution flow of the script
 ################
 
 check_python_executable;
-check_seafile_data_dir;
+read_seafile_data_dir;
 ensure_server_not_running;
 
 update_database;
@@ -202,6 +230,7 @@ move_old_customdir_outside;
 make_media_custom_symlink;
 upgrade_seafile_server_latest_symlink;
 
+add_gunicorn_conf;
 
 echo
 echo "-----------------------------------------------------------------"
